Description Format Methods Examples
Sorting creates a streaming algorithm that can be used
to sort incoming data
An R6Class generator object
new()Creates a new Sorting streamer object.
Sorting$new(x = NULL, method = "linked-list")
xvalues to be used during initialisation (optional)
methodthe method used to sort values
The new Sorting (invisibly)
update()Updates the Sorting streamer object.
Sorting$update(x)
xvalues to be added to the stream
The updated Sorting (invisibly)
clone()The objects of this class are cloneable with this method.
Sorting$clone(deep = FALSE)
deepWhether to make a deep clone.
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.